.. _astrodynx:

``astrodynx``
=============

.. currentmodule:: astrodynx

.. container:: module-header

   .. automodule:: astrodynx
      :no-index:

.. container:: module-content

   .. rubric:: Kepler Equations

   .. autosummary::
      :toctree: generated/
      :template: function.rst
      :nosignatures:

      kepler_equ_elps
      kepler_equ_hypb
      kepler_equ_uni
      generalized_anomaly
      mean_anomaly_elps
      mean_anomaly_hypb
      solve_kepler_elps
      solve_kepler_hypb
      solve_kepler_uni
      dE
      dH

   .. rubric:: Orbit Integrals

   .. autosummary::
      :toctree: generated/
      :template: function.rst
      :nosignatures:

      orb_period
      angular_momentum
      semimajor_axis
      eccentricity_vector
      semiparameter
      mean_motion
      equ_of_orbit
      equ_of_orb_uvi
      radius_periapsis
      radius_apoapsis
      semipara_from_ae
      a_from_pe

   .. rubric:: Orbit State Conversions

   .. autosummary::
      :toctree: generated/
      :template: function.rst
      :nosignatures:

      rv2coe
      coe2rv
      inclination
      true_anomaly
      right_ascension
      argument_of_periapsis

.. container:: module-footer

   .. rubric:: Module Information

   **Full name:** ``astrodynx``

   **Source:** `View source on GitHub <https://github.com/adxorg/astrodynx/blob/main/src/astrodynx>`_
